android_file_picker library

The Android implementation of the file_picker plugin.

Classes

AndroidPlatformFile
A PlatformFile implementation for Android.
AndroidSAFHandle
An opaque handle to an Android Storage Access Framework uri.
AndroidSAFOptions
Configuration options for working with Android Storage Access Framework (SAF).
FilePickerAndroid
An implementation of FilePickerPlatform for Android.
FilePickerAndroidOptions
Configuration options specific to the Android platform.

Enums

AndroidSAFAccessMode
The access mode that is coupled to an AndroidSAFGrant.
AndroidSAFGrant
The grant type for an Android Storage Access Framework grant.